=======
Credits
=======

Development Leads
-----------------

* Jeffrey S. Hazboun <jeffrey.hazboun@nanograv.org>
* Paul T. Baker <paul.baker@nanograv.org>
* Brent Shapiro-Albert <bjs0024@mix.wvu.edu>

Contributors
------------

* Joseph D. Romano <joseph.romano@nanograv.org>
* Cassidy Wagner <cassidymwagner@gmail.com>
* Amelia Henkel <amelia.henkel@uconn.edu>
* Paul Brook <paul.brook@nanograv.org>
